@@ -36,7 +36,7 @@ extern void ambapp_init(void);
 extern void ambapp_drivers_init(void);
 
 /* Create Device Nodes */
-extern void ambapp_nodes_init(void);
+extern void ambapp_nodes_init(struct node *n);
 
 /* Register the Frequency of an AHB bus. It will be used to calculate the
  * frequency of all other AHB/APB buses.
@@ -94,6 +94,7 @@ typedef struct {
 	unsigned int vendor;
 	unsigned int device;
 	unsigned char irq[32];
+	unsigned int extra;
 	unsigned char ver;
 	unsigned char bus_idx;
 	unsigned char dev_type;
@@ -106,6 +107,7 @@ typedef struct {
 	unsigned int vendor;
 	unsigned int device;
 	unsigned char irq[32];
+	unsigned int extra;
 	unsigned char ver;
 	unsigned char bus_idx;
 	unsigned char dev_type;
@@ -120,6 +122,7 @@ typedef struct {
 	unsigned int vendor;
 	unsigned int device;
 	unsigned char irq[32];
+	unsigned int extra;
 	unsigned char ver;
 	unsigned char bus_idx;
 	unsigned char dev_type;
@@ -130,7 +133,8 @@ typedef struct ambapp_core_s ambapp_core;
 struct ambapp_core_s {
 	ambapp_core *next;
 	int index; /* Index of Core */
-
+	int scanidx; /* Index of duplicate cores */
+	
 	/* Device Information */
 	ambapp_ahbdev *ahbmst;
 	ambapp_ahbdev *ahbslv;
@@ -146,6 +150,7 @@ struct ahb_bus {
 	unsigned char slv_cnt;
 	unsigned char mst_cnt;
 	unsigned char ffact;
+	unsigned char isiommu;
 	unsigned char dir; /* frequency direction relative to parent bus */
 	unsigned long freq; /* HZ */
 	ambapp_ahbdev *msts;
@@ -155,6 +160,7 @@ struct ahb_bus {
 struct apb_bus {
 	unsigned long ioarea;
 	unsigned char bus_idx;
+	unsigned char ahb_bus_idx;
 	unsigned char parent_bus_idx;
 	unsigned char slv_cnt;
 	ambapp_apbdev *slvs;
@@ -169,6 +175,10 @@ struct ambapp_bus {
 
 	/* Devices paired based in VENDOR:DEVICE:VERSION in cores */
 	ambapp_core	*cores;			/* Linked list of cores */
+
+	struct node *ahbsn[AMBA_AHB_MAX];	/* per bus node */
+	struct node **ahbsnn[AMBA_AHB_MAX];	/* bus node child-chain next pointer  */
+	
 	int core_cnt;
 };
 
@@ -207,6 +217,9 @@ extern const char *ambapp_device_id2desc(int vendor, int id);
 /* Return description of vendor */
 extern const char *ambapp_vendor_id2desc(int vendor);
 
+/* initialize a AHB device */
+extern void ambapp_dev_init_ahb(struct ahb_bus *bus, struct ambapp_pnp_ahb *ahb, ambapp_ahbdev *dev);
+
 #define DEV_NONE	0
 #define DEV_AHB_MST	1
 #define DEV_AHB_SLV	2
