@@ -54,6 +54,11 @@
 #define CONFIG_LINUX_BSS_START 0xf099f000
 #define CONFIG_LINUX_BSS_SIZE  0x0001d0d8
 
+/* Select which UART will be PROM system console, by index (0=first UART,
+ * 1=second UART, and so on)
+ */
+#define CONFIG_UART_INDEX 0
+
 /* Enable Debug Options */
 #define CONFIG_DEBUG
 
