@@ -45,6 +45,8 @@ extern char *prop_str_description;
 
 extern void opprom_init(void);
 extern void *prom_malloc(int size);
+extern void *prom_calloc(int size);
+struct node *opprom_get_ambapp0(void);
 
 /* send one character to UART, blocking until done. For debugging.
  * Works only after AMBA has been scanned or if CONFIG_DEBUG_UART has been
