@@ -389,8 +389,11 @@ void ahb2ahb_bus_create(struct ambapp_bus *ainfo, struct ahb_bus *parent,
 
 	/* Check that bus hasn't been scanned already */
 	for (i = 0; i < ainfo->ahb_buses; i++)
-		if (ainfo->ahbs[i].ioarea == ioarea)
+		if (ainfo->ahbs[i].ioarea == ioarea) {
+			/* prevent uplink slave to be selected in ambapp_core_create */
+			bridge->irq[0] |= 0x80;
 			return;
+		}
 
 	
 	/* Add new bus to AMBA Information */
